SWDEV-306122 - [catch2][dtest] Adding following tests for hipGraphEventWaitNodeSetEvent() (#2590)
- Functional Tests - Negative Tests Change-Id: I2421c3def1a7c6865dca29bde7e741948e67345d
Este cometimento está contido em:
cometido por
GitHub
ascendente
f0e03e9d45
cometimento
3a84eb3a5f
@@ -1,5 +1,5 @@
|
||||
/*
|
||||
Copyright (c) 2021 - 2021 Advanced Micro Devices, Inc. All rights reserved.
|
||||
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
|
||||
|
||||
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||
of this software and associated documentation files (the "Software"), to deal
|
||||
@@ -89,4 +89,11 @@ template <typename T> __global__ void vector_square(const T* A_d, T* C_d, size_t
|
||||
}
|
||||
}
|
||||
|
||||
template <typename T> __global__ void vector_cubic(const T* A_d, T* C_d, size_t N_ELMTS) {
|
||||
size_t gputhread = (blockIdx.x * blockDim.x + threadIdx.x);
|
||||
size_t stride = blockDim.x * gridDim.x;
|
||||
for (size_t i = gputhread; i < N_ELMTS; i += stride) {
|
||||
C_d[i] = A_d[i] * A_d[i] * A_d[i];
|
||||
}
|
||||
}
|
||||
} // namespace HipTest
|
||||
|
||||
Criar uma nova questão referindo esta
Bloquear um utilizador